#
# spec file for package xwayland
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define have_wayland_eglstream 1

#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir /var/adm/fillup-templates
%endif

Name:           xwayland
Version:        21.1.4
Release:        150400.1.12
URL:            http://xorg.freedesktop.org/
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Summary:        X
# Source URL: https://xorg.freedesktop.org/archive/individual/xserver/
License:        MIT
Group:          System/X11/Servers/XF86_4
Source0:        %{name}-%{version}.tar.xz
Source1:        %{name}-%{version}.tar.xz.sig
BuildRequires:  meson
BuildRequires:  ninja
BuildRequires:  pkgconfig
BuildRequires:  rendercheck
BuildRequires:  pkgconfig(bigreqsproto)
BuildRequires:  pkgconfig(compositeproto)
BuildRequires:  pkgconfig(damageproto)
BuildRequires:  pkgconfig(dri)
BuildRequires:  pkgconfig(dri3proto)
BuildRequires:  pkgconfig(epoxy)
BuildRequires:  pkgconfig(libtirpc)

BuildRequires:  pkgconfig(wayland-client)
BuildRequires:  pkgconfig(wayland-protocols)
%if 0%{?have_wayland_eglstream} == 1
BuildRequires:  pkgconfig(wayland-eglstream-protocols)
%endif
BuildRequires:  pkgconfig(fixesproto)
BuildRequires:  pkgconfig(fontsproto)
BuildRequires:  pkgconfig(fontutil)
BuildRequires:  pkgconfig(gbm)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glproto)
BuildRequires:  pkgconfig(inputproto)
BuildRequires:  pkgconfig(kbproto)
BuildRequires:  pkgconfig(libbsd)
BuildRequires:  pkgconfig(libdrm)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(pixman-1)
BuildRequires:  pkgconfig(presentproto)
BuildRequires:  pkgconfig(randrproto)
BuildRequires:  pkgconfig(recordproto)
BuildRequires:  pkgconfig(renderproto)
BuildRequires:  pkgconfig(resourceproto)
BuildRequires:  pkgconfig(scrnsaverproto)
BuildRequires:  pkgconfig(videoproto)
BuildRequires:  pkgconfig(xau)
BuildRequires:  pkgconfig(xcb)
BuildRequires:  pkgconfig(xcb-damage)
BuildRequires:  pkgconfig(xcb-sync)
BuildRequires:  pkgconfig(xcb-xinput)
BuildRequires:  pkgconfig(xcmiscproto)
BuildRequires:  pkgconfig(xdmcp)
BuildRequires:  pkgconfig(xextproto)
BuildRequires:  pkgconfig(xf86bigfontproto)
BuildRequires:  pkgconfig(xf86vidmodeproto)
BuildRequires:  pkgconfig(xfont2)
BuildRequires:  pkgconfig(xineramaproto)
BuildRequires:  pkgconfig(xkbcomp)
BuildRequires:  pkgconfig(xkbfile)
BuildRequires:  pkgconfig(xproto)
BuildRequires:  pkgconfig(xshmfence)
BuildRequires:  pkgconfig(xtrans)

%ifnarch s390 s390x
Requires(pre):  %fillup_prereq
%endif
Requires:       pkgconfig
Requires:       xkbcomp
#Recommends:     xorg-x11-fonts-core
%ifnarch s390 s390x
Requires:       libpixman-1-0
%endif
Obsoletes:      xorg-x11-server-wayland < %{version}
Provides:       xorg-x11-server-wayland = %{version}

%description
This package contains the Xwayland Server.

%package %{name}
Summary:        Xwayland Xserver
Group:          System/X11/Servers/XF86_4
Requires:       xkbcomp
Requires:       xkeyboard-config
Recommends:     xorg-x11-fonts-core

%description %{name}
This package contains the Xserver running on the Wayland Display Server.

%package devel
Summary:        Development files for Xwayland
Group:          System/Libraries
Requires:       %{name}
Requires:       c_compiler
Requires:       meson
Requires:       pkgconfig(libdrm)
Requires:       pkgconfig(xau)
Requires:       pkgconfig(xdmcp)
Requires:       pkgconfig(xkbfile)
Requires:       pkgconfig(xtrans)
Requires:       pkgconfig(xv)

%description devel
This package contains the Xwayland Server development files.

%prep
%setup -q -n %{name}-%{version}

%build
%define _lto_cflags %{nil}

%{meson} \
   -Dglamor=true \
%if 0%{?have_wayland_eglstream} == 1
   -Dxwayland_eglstream=true \
%endif
   -Dxvfb=true \
   -Dglx=true \
   -Dxdmcp=true \
   -Dxdm-auth-1=true \
   -Dsecure-rpc=true \
   -Dipv6=true \
   -Dinput_thread=true \
   -Dvendor_name="SUSE LINUX" \
   -Dvendor_name_short="openSUSE" \
   -Dvendor_web="https://www.opensuse.org" \
   -Dlisten_tcp=false \
   -Dlisten_unix=true \
   -Dlisten_local=true \
   -Ddpms=true \
   -Dxf86bigfont=true \
   -Dscreensaver=true \
   -Dxres=true \
   -Dxace=true \
   -Dxselinux=false \
   -Dxinerama=true \
   -Dxcsecurity=true \
   -Dxv=true \
   -Dmitshm=true \
   -Dsha1=libcrypto \
   -Ddri3=true \
   -Dxwayland-path="%{_bindir}" \
   -Ddtrace=false \
   -Dlibunwind=false \
   -Dxkb_dir="/usr/share/X11/xkb" \
   -Dxkb_output_dir="/var/lib/xkb/compiled" \
   -Ddefault_font_path="/usr/share/fonts/misc:unscaled,\
/usr/share/fonts/Type1/,/usr/share/fonts/100dpi:unscaled,\
/usr/share/fonts/75dpi:unscaled,/usr/share/fonts/ghostscript/,\
/usr/share/fonts/cyrillic:unscaled,\
/usr/share/fonts/misc/sgi:unscaled,\
/usr/share/fonts/truetype/,built-ins" \
   %{nil}

%{meson_build}

%install
%{meson_install}
# Let xorg-x11-server provide the Xserver manual
rm -f %{buildroot}%{_mandir}/man1/Xserver.1
# Provided by xorg-x11-server
rm -f %{buildroot}%{_libdir}/xorg/protocol.txt

%files
%{_bindir}/Xwayland

%files devel
%defattr(-,root,root)
%{_libdir}/pkgconfig/*.pc
%dir %{_libdir}/xorg
%{_mandir}/man1/Xwayland.1.gz

%changelog
* Tue Dec 14 2021 sndirsch@suse.com
- Update to version 21.1.4
  * Fixes for multiple input validation failures in X server extensions:
    + CVE-2021-4008/ZDI-CAN-14192 SProcRenderCompositeGlyphs out-of-bounds access (boo#1193030)
    + CVE-2021-4009/ZDI-CAN 14950 SProcXFixesCreatePointerBarrier out-of-bounds access (boo#1190487)
    + CVE-2021-4010/ZDI-CAN-14951 SProcScreenSaverSuspend out-of-bounds access (boo#1190488)
    + CVE-2021-4011/ZDI-CAN-14952 SwapCreateRegister out-of-bounds access (boo#1190489)
  * This release also includes other fixes such as:
    + Store EGLcontext to avoid superfluous eglMakeCurrent() calls
    + Prefer EGLStream with NVIDIA proprietary driver if both GBM and EGLstream are available
* Mon Nov  8 2021 sndirsch@suse.com
- Update to version 21.1.3
  * Most notable change is a fix for the GBM backend to work with
    the Nvidia driver series 495.
- supersedes U_glamor-Fix-handling-of-1-bit-pixmaps.patch
* Thu Oct  7 2021 joan.torres@suse.com
- Specfile cleanup
* Tue Sep 28 2021 sndirsch@suse.com
- U_glamor-Fix-handling-of-1-bit-pixmaps.patch
  * glamor: Fix handling of 1-bit pixmaps; fixes e.g. issues with
    gimp on Wayland (which needs Xwayland) (boo#1189310)
* Mon Sep 27 2021 sndirsch@suse.com
- covers jira#SLE/SLE-18653
* Thu Jul 15 2021 macie.mckitrick@protonmail.com
- xwayland pc is required for S390x and S390
* Fri Jul  9 2021 sndirsch@suse.com
- Update to version 21.1.2
  * The only change compared to the release candidate is a fix for
    a long standing issue where Xwayland wouldn't send events to
    notify clients of RandR configuration changes in some cases.
* Thu Jul  1 2021 sndirsch@suse.com
- Update to version 21.1.1.901 (21.1.2 RC1)
  * It's a bit special, as most of the changes are not the usual
    stable branch fixes material, but are needed for HW accelerated
    direct rendering with the Nvidia 470 driver (which is currently
    in open beta).
  * changes are mostly specific to the EGLStream backend and do not
    affect the GBM backend. And they make a big difference for users
    of the EGLStream backend.
  * See
    https://lists.fedoraproject.org/archives/list/desktop@lists.fedoraproject.org/thread/BBZVDNST67I2AQOCPSHKYAY6D5Z66JIP/
    for more information about testing the EGLStream changes
- enabled Wayland eglstreams (needs new packages egl-wayland and
  eglexternalplatform)
* Tue Apr 13 2021 sndirsch@suse.com
- Update to version 21.1.1
  * Fix XChangeFeedbackControl() request underflow (CVE-2021-3472,
    ZDI-CAN-1259, bsc#1180128)
* Mon Apr 12 2021 tobias.klausmann@freenet.de
- Additionally to not packing /usr/lib64/xorg/protocol.txt, delete it to fix
  the build
* Mon Apr 12 2021 gmbr3@opensuse.org
- Make vendor name the same as xorg-x11-server
* Mon Apr 12 2021 sndirsch@suse.com
- removed conflicting /usr/lib64/xorg/protocol.txt (already in
  xorg-x11-server package)
* Wed Apr  7 2021 sndirsch@suse.com
- added summary for -devel package
- some cleanup
* Wed Mar 17 2021 tobias.klausmann@freenet.de
- Update to version 21.1.0:
  * meson: Make sure XKM_OUTPUT_DIR has a trailing slash
  * xwayland: Fix LeaveNotify for relative pointer
- Highlights compared to xserver 1.20.10:
  * Xwayland's XVideo support (via glamor) now supports NV12
  * glamor can now accelerate some more RENDER extension formats
  * Xwayland's GLX provider now uses the EGL implementation instead of Mesa's
    swrast_dri.so directly
  * Xwayland can now use the wp_viewport Wayland protocol for up-scaling of
    fullscreen applications setting lower resolutions via the RandR /
    XFree86-VidModeExtension extensions
  * Xwayland now alternates between multiple buffers for all Wayland surfaces,
    making it less of a special case compared to other Wayland clients
  * Xwayland can now use memfd_create for creating buffers shared with the
    Wayland compositor when glamor hardware acceleration is disabled
  * Xwayland has better support for clients using relative mouse input and
    keyboard grabs
  * An Xwayland.1 manpage is now installed
  * Xwayland now supports -listenfd, -version and -verbose command line options
  * Xwayland now installs an xwayland.pc file which helps discovering the path
    of the installed Xwayland binary and the features it supports
  * Only meson is supported for building
  * Only Xwayland and Xvfb can be built, only Xwayland can be installed
* Thu Mar  4 2021 sndirsch@suse.com
- update to 21.0.99.902
  * second release candidate for the standalone Xwayland 21.1.0 release
  * meson.build: Keep the protocol version looking like xserver 1.20.x did
  * xwayland: Delay cursor visibility update
* Fri Feb 26 2021 sndirsch@suse.com
- added Buildrequires to pkgconfig(glproto) and pkgconfig(gl) to
  fix build on Leap
* Fri Feb 19 2021 tobias.klausmann@freenet.de
- Initial stand-alone Xwayland package version 21.0.99.901 (boo#1182677)
